#define MFBSOLIDFILLAREA xf1bppSolidWhiteArea
#define MFBSTIPPLEFILLAREA xf1bppStippleWhiteArea
#define OPEQ |=
#define EQWHOLEWORD =~0
#include "mfbmap.h"
#include "../../../mfb/mfbpntarea.c"
